@@ -32,6 +32,14 @@ def write_conf(args):
         service_item["volumes"] = args.volumes
     if args.ports is not None:
         service_item["ports"] = args.ports
+        for port in args.ports:
+            port_p = port.split(":")
+            if port_p[0] != port_p[1]:
+                break
+        else:
+            service_item["network_mode"] = "host"
+            del service_item["ports"]
+
     if args.restart is not None:
         service_item["restart"] = args.restart
     if args.command is not None:
@@ -87,5 +95,6 @@ def main():
 
 if __name__ == "__main__":
     sys.argv.extend(["--debug", "config", "-n", "qc", "-i", "meisanggou/qc", "-v", "${JINGD_DATA_ROOT}:${JINGD_DATA_ROOT}",
-                     "-v", "${JINGD_CONF_DIR}:${JINGD_CONF_DIR}", "-v", "${GATCAPI_DIR}/Worker:/opt/worker", "-w", "/opt/worker", "python", "SampleSequencingLocalWorker.py"])
+                     "-v", "${JINGD_CONF_DIR}:${JINGD_CONF_DIR}", "-p", "6379:6379", "-v", "${GATCAPI_DIR}/Worker:/opt/worker",
+                     "-w", "/opt/worker", "python", "SampleSequencingLocalWorker.py"])
     main()
